@@ -30,6 +30,7 @@ from typing import cast
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import TypeVar
 from typing import Union
 
 import arrow
@@ -41,13 +42,11 @@ from rich import traceback
 from rich.logging import RichHandler
 from yt_dlp import YoutubeDL
 
-from playlist2podcast import __version__
-from playlist2podcast import CODE_VERSION_MAJOR
-from playlist2podcast import CODE_VERSION_MINOR
-from playlist2podcast import CODE_VERSION_PATCH
+from . import __version__
 
 traceback.install(show_locals=True)
 
+CFG = TypeVar("CFG", bound="Configuration")
 
 YDL_DL_OPTS = {
     "quiet": "true",
@@ -85,7 +84,7 @@ class Configuration:
     log_level: str
     youtube_cookie_file: Optional[str]
 
-    def __init__(self, config_file_name: str) -> None:
+    def __init__(self: CFG, config_file_name: str) -> None:
 
         if os.path.exists(config_file_name):
             with open(file=config_file_name, encoding="UTF-8") as config_file:
@@ -155,7 +154,7 @@ class Configuration:
         with open(file=config_file_name, mode="w", encoding="UTF-8") as config_file:
             json.dump(asdict(self), config_file, indent=4)
 
-    def __collect_playlists_info(self) -> None:
+    def __collect_playlists_info(self: CFG) -> None:
         """Prompts user to enter playlist urls and any associated
         include/exclude filters."""
         self.play_lists = []
@@ -237,7 +236,7 @@ def main() -> None:
     std_out_handler.setLevel(config.log_level)
     logger.addHandler(std_out_handler)
 
-    check_updates(logger)
+    logger.info("Welcome to Playlist2Podcast version %s", __version__)
 
     feed = FeedGenerator()
     feed.author(name="Marvin", email="marvin@example.com")
@@ -246,15 +245,17 @@ def main() -> None:
     feed.title("Marvin's Youtube Playlist Podcast")
     feed.description("Marvin's Youtube Playlist Podcast")
 
-    download_options = YDL_DL_OPTS
-    if config.youtube_cookie_file and config.youtube_cookie_file != "":
-        download_options["cookiefile"] = config.youtube_cookie_file
-    downloader = YoutubeDL(download_options)
-
     for current_play_list in config.play_lists:
         logger.info(
             "Downloading info for videos on playlist: %s", current_play_list["url"]
         )
+
+        download_options = YDL_DL_OPTS
+        download_options["playlistend"] = config.number_of_episodes * 3
+        if config.youtube_cookie_file and config.youtube_cookie_file != "":
+            download_options["cookiefile"] = config.youtube_cookie_file
+        downloader = YoutubeDL(download_options)
+
         videos_list = downloader.extract_info(current_play_list["url"], download=False)[
             "entries"
         ]
@@ -264,10 +265,11 @@ def main() -> None:
             for video in videos_list
             if video
             and is_video_included(
-                video["title"],
-                cast(List[str], current_play_list["include"]),
-                cast(List[str], current_play_list["exclude"]),
-                logger,
+                video_title=video["title"],
+                video_original_url=video["original_url"],
+                include_filters=cast(List[str], current_play_list["include"]),
+                exclude_filters=cast(List[str], current_play_list["exclude"]),
+                logger=logger,
             )
         ]
 
@@ -283,6 +285,7 @@ def main() -> None:
 
 def is_video_included(
     video_title: str,
+    video_original_url: str,
     include_filters: List[str],
     exclude_filters: List[str],
     logger: logging.Logger,
@@ -291,6 +294,7 @@ def is_video_included(
     video should be considered for adding to podcast or not.
 
     :param video_title: Title of video to check filters against.
+    :param video_original_url: Original URL of video to check filters against.
     :param include_filters: List of regex patterns acting as include filters.
         If one include filter matches, video will be considered for adding.
     :param exclude_filters: Lost of regex patterns actins as exclude filters.
@@ -300,33 +304,46 @@ def is_video_included(
     :return: True if video should be considered for adding and False if video should
         be skipped based on filters.
     """
-    logger.debug(f"Filter checking video: {video_title}")
+    logger.debug(
+        f"Filtering: Checking video: '{video_title}' at '{video_original_url}'"
+    )
 
     should_include_video = False
 
+    title_len = len(video_title)
+    url_len = len(video_original_url)
+
+    if title_len == 0 and url_len == 0:
+        return should_include_video
+
     if len(include_filters) == 0:
         should_include_video = True
 
     else:
         for include_filter in include_filters:
             regex = re.compile(include_filter)
-            if regex.match(video_title):
-                logger.debug(
-                    f"Include filter '{include_filter}' matches ... "
-                    f"considering: {video_title}"
-                )
+            if title_len and regex.match(video_title):
+                logger.debug(f"Filtering: Include filter '{include_filter}' matches")
                 should_include_video = True
+                break
+            if url_len and regex.match(video_original_url):
+                logger.debug(f"Filtering: Include filter '{include_filter}' matches")
+                should_include_video = True
+                break
 
     if len(exclude_filters) > 0:
         for exclude_filter in exclude_filters:
             regex = re.compile(exclude_filter)
-            if regex.match(video_title):
-                logger.debug(
-                    f"Exclude filter '{exclude_filter}' matches ... "
-                    f"skipping: {video_title}"
-                )
+            if title_len and regex.match(video_title):
+                logger.debug(f"Filtering: Exclude filter '{exclude_filter}' matches")
                 should_include_video = False
                 break
+            if url_len and regex.match(video_original_url):
+                logger.debug(f"Filtering: Exclude filter '{exclude_filter}' matches")
+                should_include_video = False
+                break
+
+    logger.debug(f"Filtering: Video '{video_title}' included? {should_include_video}")
 
     return should_include_video
 
@@ -446,55 +463,5 @@ def get_thumbnail(config: Configuration, video_id: str, video: Dict[str, Any]) -
     return publish_image
 
 
-def check_updates(logger: logging.Logger) -> None:
-    """Check of there is a newer version of MastodonAmnesia available on
-    gitlab.
-
-    :param logger: Logger object to be able to send message to log
-    :return: None
-    """
-    try:
-        response = httpx.get(
-            "https://codeberg.org/PyYtTools/Playlist2Podcasts"
-            "/raw/branch/main/update-check/release-version.txt"
-        )
-        response.raise_for_status()
-        repo_version = response.content.decode("utf-8").strip().partition(".")
-        repo_version_major = int(repo_version[0].strip())
-        repo_minor_version_to_check = repo_version[2].strip().partition(".")
-        repo_version_minor = int(repo_minor_version_to_check[0].strip())
-        repo_version_patch = int(repo_minor_version_to_check[2].strip())
-
-        code_version_numeric = CODE_VERSION_MAJOR * 1000000
-        code_version_numeric += CODE_VERSION_MINOR * 1000
-        code_version_numeric += CODE_VERSION_PATCH
-        repo_version_numeric = repo_version_major * 1000000
-        repo_version_numeric += repo_version_minor * 1000
-        repo_version_numeric += repo_version_patch
-
-        if code_version_numeric >= repo_version_numeric:
-            logger.info(
-                f"Playlist2Podcast v{CODE_VERSION_MAJOR}."
-                f"{CODE_VERSION_MINOR}.{CODE_VERSION_PATCH} is up to date."
-            )
-        else:
-            logger.warning(
-                f"New version of Playlist2Podcast"
-                f" (v{repo_version_major}.{repo_version_minor}.{repo_version_patch})"
-                f" is available!"
-            )
-            logger.warning(
-                f"(You have v{CODE_VERSION_MAJOR}."
-                f"{CODE_VERSION_MINOR}.{CODE_VERSION_PATCH})"
-            )
-            logger.warning(
-                "Latest available at: https://codeberg.org/PyYtTools/Playlist2Podcasts"
-            )
-    except (httpx.ConnectError, httpx.HTTPError) as update_check_error:
-        logger.warning(
-            "Encountered error while checking for updates: %s", update_check_error
-        )
-
-
 if __name__ == "__main__":
     main()
